.. _contributing_label:

Contributing
============

Contributions to oemof :ref:`packages_label` are very welcome! Each of the :ref:`packages_label` is maintained individually, but in general community-based development is envisaged.
This repository is only used for organisational purposes and spans an umbrella across the individual oemof libraries.
The source code is published under the conditions of the open source `MIT license <https://choosealicense.com/licenses/mit/>`_ making sure that the code can be used, edited, and re-distributed by others.

Twice a year (usually May and December) we organise a developer meeting. The meeting dates are announced on `wwww.oemof.org <https://oemof.org>`_.

If you're interested in maintaining oemof libraries more frequently, consider to join a `developing teams <https://github.com/orgs/oemof/teams>`_.
Get in touch with us `here <https://github.com/oemof/organisation/issues/26>`_.
